# neon-goby

Email body cleaner

![neon_goby](https://user-images.githubusercontent.com/7908951/74209960-cfb0e880-4cc4-11ea-842a-6abb6e0b11ac.png)

### Install

The quick way:
```
pip install neon-goby
```


### Usage

```
from neon_goby import NeonGoby

NeonGoby.parse(<email_body>)
```
Both html and text representations are supported.
